@@ -17,7 +17,19 @@ var path = require("path")
 
 module.exports = addNamed
 
-var NAME_PREFIX = "addName:"
+function getOnceFromRegistry (name, from, next, done) {
+  mapToRegistry(name, npm.config, function (er, uri) {
+    if (er) return done(er)
+
+    var key = "registry:" + uri
+    next = inflight(key, next)
+    if (!next) return log.verbose(from, key, "already in flight; waiting")
+    else log.verbose(from, key, "not in flight; fetching")
+
+    registry.get(uri, null, next)
+  })
+}
+
 function addNamed (name, version, data, cb_) {
   assert(typeof name === "string", "must have module name")
   assert(typeof cb_ === "function", "must have callback")
@@ -30,10 +42,6 @@ function addNamed (name, version, data, cb_) {
     cb_(er, data)
   }
 
-  cb_ = inflight(NAME_PREFIX + key, cb_)
-
-  if (!cb_) return
-
   log.silly("addNamed", "semver.valid", semver.valid(version))
   log.silly("addNamed", "semver.validRange", semver.validRange(version))
   var fn = ( semver.valid(version, true) ? addNameVersion
@@ -51,17 +59,14 @@ function addNameTag (name, tag, data, cb) {
     tag = npm.config.get("tag")
   }
 
-  mapToRegistry(name, npm.config, function (er, uri) {
-    if (er) return cb(er)
-
-    registry.get(uri, null, next)
-  })
+  getOnceFromRegistry(name, "addNameTag", next, cb)
 
   function next (er, data, json, resp) {
-    if (!er) {
-      er = errorResponse(name, resp)
-    }
+    if (!er) er = errorResponse(name, resp)
     if (er) return cb(er)
+
+    log.silly("addNameTag", "next cb for", name, "with tag", tag)
+
     engineFilter(data)
     if (data["dist-tags"] && data["dist-tags"][tag]
         && data.versions[data["dist-tags"][tag]]) {
@@ -106,11 +111,7 @@ function addNameVersion (name, v, data, cb) {
     return next()
   }
 
-  mapToRegistry(name, npm.config, function (er, uri) {
-    if (er) return cb(er)
-
-    registry.get(uri, null, setData)
-  })
+  getOnceFromRegistry(name, "addNameVersion", setData, cb)
 
   function setData (er, d, json, resp) {
     if (!er) {
@@ -148,16 +149,21 @@ function addNameVersion (name, v, data, cb) {
     fs.stat(pkgtgz, function (er) {
       if (!er) {
         readJson(pkgjson, function (er, data) {
-          er = needName(er, data)
-          er = needVersion(er, data)
-          if (er && er.code !== "ENOENT" && er.code !== "ENOTDIR")
-            return cb(er)
+          if (er && er.code !== "ENOENT" && er.code !== "ENOTDIR") return cb(er)
+
+          if (data) {
+            if (!data.name) return cb(new Error("No name provided"))
+            if (!data.version) return cb(new Error("No version provided"))
+
+            // check the SHA of the package we have, to ensure it wasn't installed
+            // from somewhere other than the registry (eg, a fork)
+            if (data._shasum && dist.shasum && data._shasum !== dist.shasum) {
+              return fetchit()
+            }
+          }
+
           if (er) return fetchit()
-          // check the SHA of the package we have, to ensure it wasn't installed
-          // from somewhere other than the registry (eg, a fork)
-          if (data._shasum && dist.shasum && data._shasum !== dist.shasum)
-            return fetchit()
-          return cb(null, data)
+            else return cb(null, data)
         })
       } else return fetchit()
     })
@@ -192,17 +198,14 @@ function addNameVersion (name, v, data, cb) {
 function addNameRange (name, range, data, cb) {
   range = semver.validRange(range, true)
   if (range === null) return cb(new Error(
-    "Invalid version range: "+range))
+    "Invalid version range: " + range
+  ))
 
   log.silly("addNameRange", {name:name, range:range, hasData:!!data})
 
   if (data) return next()
 
-  mapToRegistry(name, npm.config, function (er, uri) {
-    if (er) return cb(er)
-
-    registry.get(uri, null, setData)
-  })
+  getOnceFromRegistry(name, "addNameRange", setData, cb)
 
   function setData (er, d, json, resp) {
     if (!er) {
@@ -270,15 +273,3 @@ function errorResponse (name, response) {
   }
   return er
 }
-
-function needName(er, data) {
-  return er ? er
-       : (data && !data.name) ? new Error("No name provided")
-       : null
-}
-
-function needVersion(er, data) {
-  return er ? er
-       : (data && !data.version) ? new Error("No version provided")
-       : null
-}
