@@ -168,11 +168,11 @@ Object.defineProperty(exports, "defaults", {get: function () {
     , heading: "npm"
     , "ignore-scripts": false
     , "init-module": path.resolve(home, ".npm-init.js")
-    , "init.author.name" : ""
-    , "init.author.email" : ""
-    , "init.author.url" : ""
-    , "init.version": "1.0.0"
-    , "init.license": "ISC"
+    , "init-author-name" : ""
+    , "init-author-email" : ""
+    , "init-author-url" : ""
+    , "init-version": "1.0.0"
+    , "init-license": "ISC"
     , json: false
     , key: null
     , link: false
@@ -270,11 +270,11 @@ exports.types =
   , "heading": String
   , "ignore-scripts": Boolean
   , "init-module": path
-  , "init.author.name" : String
-  , "init.author.email" : String
-  , "init.author.url" : ["", url]
-  , "init.license": String
-  , "init.version": semver
+  , "init-author-name" : String
+  , "init-author-email" : String
+  , "init-author-url" : ["", url]
+  , "init-license": String
+  , "init-version": semver
   , json: Boolean
   , key: [null, String]
   , link: Boolean
